<?php

namespace Webhopers\Erp\Policies;

use Litepie\User\Contracts\UserPolicy;
use Webhopers\Erp\Models\Departments;

class DepartmentsPolicy
{

    /**
     * Determine if the given user can view the departments.
     *
     * @param UserPolicy $user
     * @param Departments $departments
     *
     * @return bool
     */
    public function view(UserPolicy $user, Departments $departments)
    {
        if ($user->canDo('erp.departments.view') && $user->isAdmin()) {
            return true;
        }

        return $departments->user_id == user_id() && $departments->user_type == user_type();
    }

    /**
     * Determine if the given user can create a departments.
     *
     * @param UserPolicy $user
     * @param Departments $departments
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('erp.departments.create');
    }

    /**
     * Determine if the given user can update the given departments.
     *
     * @param UserPolicy $user
     * @param Departments $departments
     *
     * @return bool
     */
    public function update(UserPolicy $user, Departments $departments)
    {
        if ($user->canDo('erp.departments.edit') && $user->isAdmin()) {
            return true;
        }

        return $departments->user_id == user_id() && $departments->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given departments.
     *
     * @param UserPolicy $user
     * @param Departments $departments
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Departments $departments)
    {
        return $departments->user_id == user_id() && $departments->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given departments.
     *
     * @param UserPolicy $user
     * @param Departments $departments
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Departments $departments)
    {
        if ($user->canDo('erp.departments.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given departments.
     *
     * @param UserPolicy $user
     * @param Departments $departments
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Departments $departments)
    {
        if ($user->canDo('erp.departments.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
