<?php

namespace Webhopers\Erp\Providers;

use Illuminate\Support\ServiceProvider;

class ErpServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'erp');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'erp');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('webhopers.erp', function ($app) {
            return $this->app->make('Webhopers\Erp\Erp');
        });

                // Bind Departments to repository
        $this->app->bind(
            'Webhopers\Erp\Interfaces\DepartmentsRepositoryInterface',
            \Webhopers\Erp\Repositories\Eloquent\DepartmentsRepository::class
        );

        $this->app->register(\Webhopers\Erp\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Webhopers\Erp\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['webhopers.erp'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('webhopers/erp.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/erp')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/erp')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
